@@ -5,8 +5,9 @@ converting verse ids back into normalized references, and formatting
 references as human-readable strings.
 """
 
-__version__ = "0.0.4"
+__version__ = "0.1.0"
 
+from .bible.osis.parser import OSISParser
 from .books import Book
 from .converter import (
     convert_reference_to_verse_ids,
@@ -14,7 +15,12 @@ from .converter import (
     convert_verse_ids_to_references,
 )
 from .errors import InvalidChapterError, InvalidVerseError
-from .formatter import format_scripture_references
+from .formatter import (
+    format_scripture_references,
+    format_scripture_text,
+    format_single_reference,
+    get_parser,
+)
 from .parser import (
     get_references,
     normalize_reference,
@@ -34,3 +40,4 @@ from .verses import (
     get_verse,
     get_verse_id,
 )
+from .versions import Version
